/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.model;

import java.util.Date;

/**
 * Wraps a <i>SourceForge</i> release.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class SfRelease extends Identified {
    /** Name of its package. */
    private String packageName;
    /** URL pointing to the package page on the SF site. */
    private String packageUrl;
    /** Version. */
    private String version;
    /** URL pointing to the version page on the SF site. */
    private String versionUrl;
    /** Release date. */
    private Date date;

    /**
     * By design this should be private to avoid instantiation
     * without discriminator, but Hessian needs default ctor.
     */
    public SfRelease() {
        super(null);
    }

    public SfRelease(String packageName, String packageUrl, String version, String versionUrl, Date date) {
        super(packageName + version + date.getTime());

        this.packageName = packageName;
        this.packageUrl = packageUrl;
        this.version = version;
        this.versionUrl = versionUrl;
        this.date = date;
    }

    public String getPackageName() {
        return packageName;
    }

    public String getPackageUrl() {
        return packageUrl;
    }

    public String getVersion() {
        return version;
    }

    public String getVersionUrl() {
        return versionUrl;
    }

    public Date getDate() {
        return date;
    }

    /** Returns its age in milliseconds. */
    public long getAge() {
        return new Date().getTime() - date.getTime();
    }

    /** Returns its age in days. */
    public long getAgeInDays() {
        return getAge()/ModelUtils.MILLIS_PER_DAY;
    }

    @Override
    public String toString() {
        return String.format("%s [%s], %s [%s], %s", packageName, packageUrl, version, versionUrl, date);
    }
}
