/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.server;

import java.io.InputStream;

/**
 * Any pluggable store implementation must implement this interface.
 * The concrete implementations can have their own naming policy,
 * cache eviction policy, storing mechanism and such.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public interface StaticContentStore {
    /**
     * Called before a service starts storing its files.
     * A service call results in the sequence:
     * <pre>
     * begin()
     * storeFile()
     * storeFile()
     * ...
     * end()
     * </pre>
     * This can be used mostly for optimization purposes.
     * Leave the implementation empty if there is no way to optimize
     * "bulk storings" in your concrete implementation.
     * @see #end()
     */
    public void begin();
    /**
     * Called after a service has stored all its files.
     * @see #begin()
     */
    public void end();

    /**
     * Stores the passed stream to an implementation-dependent "storage".
     * @return the absolute URL that points to the resulted file.
     */
    public String storeFile(String fileName, InputStream in) throws Exception;
}
