/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.server.svn;

import hu.midori.kosmos.model.ScmRepositoryChange;
import hu.midori.kosmos.model.ZoomableImageLocator;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.jfree.data.time.TimeSeries;
import org.jfree.data.time.Week;

/** Wraps the stats retrieved from the content of a SVN repository. */
class SvnRepositoryLogStats {// TODO rewrite as bean
    public Date createdDate;
    /** Full history of the commits in reversed order. */
    public List<ScmRepositoryChange> commits = new ArrayList<ScmRepositoryChange>();

    /* No of commits over a certain period. */
    public int commitsTotal;
    public int commitsToday;
    public int commitsLast7Days;
    public int commitsLast31Days;

    /* Author of commits over a certain period. */
    public Set<String> committersTotal = new HashSet<String>();
    public Set<String> committersToday = new HashSet<String>();
    public Set<String> committersLast7Days = new HashSet<String>();
    public Set<String> committersLast31Days = new HashSet<String>();

    /* No of repository entries per week. */
    public TimeSeries repoEntriesPerWeek = new TimeSeries("", Week.class);
    public ZoomableImageLocator repoEntriesPerWeekChartLocator;

    /* No of commits per author. */
    public List<Map.Entry<String,Integer>> commitsPerAuthor;
    public ZoomableImageLocator commitsPerAuthorChartLocator;

    /* No of commits per file. */
    public List<Map.Entry<String,Integer>> commitsPerFile;
    public ZoomableImageLocator commitsPerFileChartLocator;

    /* No of commits per week. */
    public TimeSeries commitsPerWeek = new TimeSeries("", Week.class);
    public ZoomableImageLocator commitsPerWeekChartLocator;

    /** Must be called to validate its content, after the processing was done. */
    public void validate() {
        // revert history
        Collections.reverse(commits);

        // cummulate files-per-week values
        for(int i = 1; i < repoEntriesPerWeek.getItemCount(); i++)
            repoEntriesPerWeek.update(i, repoEntriesPerWeek.getValue(i).intValue() + repoEntriesPerWeek.getValue(i - 1).intValue());

        // add files-per-week value for the current week even if no activity
        Week currentWeek = new Week(new Date());
        if(repoEntriesPerWeek.getDataItem(currentWeek) == null)
            repoEntriesPerWeek.add(currentWeek, repoEntriesPerWeek.getValue(repoEntriesPerWeek.getItemCount() - 1));

        // assert calculations
        int calculatedCommitsTotal = 0;
        for(int i = 0; i < commitsPerWeek.getItemCount(); i++) // FIXME these kind of counting should be rather done with a commons Bag
            calculatedCommitsTotal += commitsPerWeek.getDataItem(i).getValue().intValue();
        if(calculatedCommitsTotal != commitsTotal)
            throw new IllegalStateException(String.format("Calculated commits (%d) does not equal statistical commits (%d)", calculatedCommitsTotal, commitsTotal));
    }
}